@@ -4,4 +4,4 @@ import timeit
 def f():
     rsplitter.split("wethepeopleoftheunitedstatesinordertoformamoreperfectunionestablishjusticeinsuredomestictranquilityprovideforthecommondefencepromotethegeneralwelfareandsecuretheblessingsoflibertytoourselvesandourposteritydoordainandestablishthisconstitutionfortheunitedstatesofamerica")
 
-print(timeit.timeit(f, number=10000))
\ No newline at end of file
+print(f())
\ No newline at end of file
